@@ -125,7 +125,10 @@ VOIDRET opiepututmpentry FUNCTION((line, UTMPX), char *line AND
     perror("getutmp");
     goto l1;
   }
+
+#ifdef HAVE_ONE_ARG_GETTIMEOFDAY
   gettimeofday(&utmpx->ut_tv, NULL);
+#endif /* HAVE_ONE_ARG_GETTIMEOFDAY */  
 
   i = 0;
 
