@@ -11,6 +11,8 @@ License Agreement applies to this software.
 
         History:
 
+	Modified by cmetz for OPIE 2.22. Don't include stdio.h.
+	     Use opienewseed(). Don't include unneeded headers.
 	Modified by cmetz for OPIE 2.2. Use FUNCTION declaration et al.
              Changed use of gethostname() to uname(). Ifdefed around some
              headers.
@@ -18,20 +20,6 @@ License Agreement applies to this software.
 */
 
 #include "opie_cfg.h"
-
-#if DEBUG
-#include <stdio.h>
-#endif /* DEBUG */
-#if HAVE_UNISTD_H
-#include <unistd.h>
-#endif /* HAVE_UNISTD_H */
-#if HAVE_SYS_PARAM_H
-#include <sys/param.h>
-#endif /* HAVE_SYS_PARAM_H */
-#if HAVE_SYS_UTSNAME_H
-#include <sys/utsname.h>
-#endif /* HAVE_SYS_UTSNAME_H */
-
 #include "opie.h"
 
 /* Generate a random challenge */
@@ -39,18 +27,11 @@ License Agreement applies to this software.
    most situations; it is certainly better than a fixed string */
 VOIDRET opierandomchallenge FUNCTION((prompt), char *prompt)
 {
-  time_t now;
-  struct utsname utsname;
+  char buf[OPIE_SEED_MAX + 1];
 
-  time(&now);
-  srand(now);
-  now = rand();
+  buf[0] = 0;
+  if (opienewseed(buf))
+    strcpy(buf, "ke44529");
 
-  if (uname(&utsname) < 0) {
-    perror("uname");
-    utsname.nodename[0] = 'k';
-    utsname.nodename[1] = 'e';
-  }
-  utsname.nodename[2] = 0;
-  sprintf(prompt, "otp-md%d %d %s%04d", MDX, (rand() % 499) + 1, utsname.nodename, (now % 9998) + 1);
+  sprintf(prompt, "otp-md%d %d %s", MDX, (rand() % 499) + 1, buf);
 }
