@@ -1,11 +1,8 @@
 /* unlock.c: The opieunlock() library function.
 
-%%% portions-copyright-cmetz
 Portions of this software are Copyright 1996 by Craig Metz, All Rights
-Reserved. The Inner Net License Version 2 applies to these portions of
-the software.
-You should have received a copy of the license with this software. If
-you didn't get a copy, you may request one from <license@inner.net>.
+Reserved. The Inner Net Copyright Notice and License Agreement applies to
+these portions of the software.
 
 Portions of this software are Copyright 1995 by Randall Atkinson and Dan
 McDonald, All Rights Reserved. All Rights under this copyright are assigned
@@ -14,8 +11,6 @@ License Agreement applies to this software.
 
         History:
 
-	Modified by cmetz for OPIE 2.3. Do refcounts whether or not
-            we actually lock. Fixed USER_LOCKING=0 case.
 	Modified by cmetz for OPIE 2.22. Added reference count support.
 	    Changed lock filename/refcount symbol names to better indicate
 	    that they're not user serviceable.
@@ -31,10 +26,8 @@ License Agreement applies to this software.
 #include <fcntl.h>
 #include "opie.h"
 
-extern int __opie_lockrefcount;
-#if USER_LOCKING
 extern char *__opie_lockfilename;
-#endif /* USER_LOCKING */
+extern int __opie_lockrefcount;
 
 /* 
   Just remove the lock, right?
@@ -42,7 +35,7 @@ extern char *__opie_lockfilename;
 */
 int opieunlock FUNCTION_NOARGS
 {
-#if USER_LOCKING
+#ifdef USER_LOCKING
   int fh, rval = -1, pid, t, i;
   char buffer[128], *c, *c2;
 
@@ -95,9 +88,6 @@ unlockret1:
   __opie_lockfilename = NULL;
   return rval;
 #else /* USER_LOCKING */
-  if (__opie_lockrefcount-- > 0)
-    return 0;
-
-  return -1;
+  return 0;
 #endif /* USER_LOCKING */
 }
