@@ -11,6 +11,10 @@ License Agreement applies to this software.
 
 	History:
 
+	Modified by cmetz for OPIE 2.22. Call setlogin(). Decreased default
+	        timeout to two minutes. Use opiereadpass() flags to get
+		around Solaris drain bamage.
+	Modified by cmetz for OPIE 2.21. Took the sizeof() the wrong thing.
         Modified by cmetz for OPIE 2.2. Changed prompts to ask for OTP
                 response where appropriate. Simple though small speed-up.
                 Don't allow cleartext if echo on. Don't try to clear
@@ -167,10 +171,7 @@ static struct passwd thisuser;
 #include <shadow.h>
 #endif /* HAVE_SHADOW_H */
 
-#if DOTTYPROMPT
 static char *ttyprompt;
-static int first = 1;
-#endif /* DOTTYPROMPT */
 
 #ifdef PERMSFILE
 extern char *home;
@@ -196,7 +197,7 @@ static char lastlog[] = _PATH_LASTLOG;
  * We initialize it here for safety and so that it can be
  * patched on machines where the default value is not appropriate.
  */
-static int timeout = 300;
+static int timeout = 120;
 
 static void getstr __P((char *, int, char *));
 
@@ -277,29 +278,30 @@ static VOIDRET getloginname FUNCTION_NOARGS
 {
   register char *namep;
   char c, d;
+  int flags;
+  static int first = 1;
 
   memset(name, 0, sizeof(name));
 
   d = 0;
   while (name[0] == '\0') {
-#if DOTTYPROMPT
+    flags = 1;
     if (ttyprompt) {
-      if (first)
+      if (first) {
+	flags = 6;
 	first--;
-      else
+      } else
 	printf(ttyprompt);
     } else
-#endif /* DOTTYPROMPT */
       printf("login: ");
     fflush(stdout);
     if (++d == 3)
       exit(0);
-    if (!opiereadpass(name, sizeof(name)-1, 1)) {
+    if (!opiereadpass(name, sizeof(name)-1, flags)) {
       syslog(LOG_CRIT, "End-of-file (or other error?) on stdin!");
       exit(0);
     }
     for (namep = name; *namep; namep++) {
-/*      namep &= 0x7f; */
         if (c == ' ')
           c = '_'; 
     }
@@ -1181,6 +1183,9 @@ completeness, but these are set within appropriate defines for portability. */
 #endif	/* USER_PROCESS */
 
   opiepututmpentry(tty, &UTMPX);
+#if HAVE_SETLOGIN
+  setlogin(name);
+#endif /* HAVE_SETLOGIN */
 
   quietlog = !access(QUIET_LOGIN_FILE, F_OK);
 
@@ -1206,7 +1211,7 @@ completeness, but these are set within appropriate defines for portability. */
 
     time(&ll.ll_time);
     strncpy(ll.ll_line, tty, sizeof(ll.ll_line));
-    strncpy(ll.ll_host, host, sizeof(ll.ll_line));
+    strncpy(ll.ll_host, host, sizeof(ll.ll_host));
     write(f, (char *) &ll, sizeof ll);
     close(f);
   }
